(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[     97240,       1874]
NotebookOptionsPosition[     97444,       1861]
NotebookOutlinePosition[     98133,       1885]
CellTagsIndexPosition[     98090,       1882]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Internal Forces in a Beam 1\n",
 StyleBox["Qingchang Liu, Baoxing Xu \nUniversity of Virginia, 2017-10-16",
  FontSize->16,
  FontColor->GrayLevel[0]]
}], "Title",
 TextAlignment->Center,
 ExpressionUUID -> "1f0b3856-036c-4559-ac86-a359a58bd3e2"],

Cell[TextData[{
 "To design a structural or mechanical member it is necessary to know the \
loading acting within the member in order to be sure the material can resist \
this loading. Internal loadings can be determined by using the ",
 StyleBox["method of sections",
  FontSlant->"Italic"],
 ". To illustrate this method, this module will show you how to determine the \
internal loadings. \n",
 StyleBox["Normal force",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 ": The force component that acts perpendicular to the cross section.\n",
 StyleBox["Shear force",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 ": The force component that is tangent to the cross section.\n",
 StyleBox["Bending moment",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 ": The couple moment within the section.\nThe force components prevent the \
relative translation between the two segments, and the couple moment prevents \
the relative rotation. According to Newton\[CloseCurlyQuote]s third law, \
these loadings must act in opposite directions on each segment."
}], "Text",
 ExpressionUUID -> "50edfe98-c88f-49cd-b9d2-e658b33bf322"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`bd$$ = 1, $CellContext`dirf$$ = 
    120, $CellContext`dirm$$ = 1, $CellContext`int$$ = 0, $CellContext`mf$$ = 
    0.25, $CellContext`mm$$ = 0.25, $CellContext`nd$$ = 
    1, $CellContext`opa1$$ = 0, $CellContext`opa2$$ = 1, $CellContext`pf$$ = 
    0.4, $CellContext`pm$$ = 0.6, $CellContext`ps$$ = 
    0.25, $CellContext`reac$$ = 0, $CellContext`sd$$ = 
    1, $CellContext`step1$$ = 0, $CellContext`step2$$ = 
    0, $CellContext`step3$$ = 0, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`opa1$$], 0, 
       Row[{"Coordinates visibility", 
         Spacer[55]}]}, {1 -> "On", 0 -> "off"}}, {{
       Hold[$CellContext`step1$$], 0, 
       Row[{
        "\!\(\*\nStyleBox[\"Step\",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\
\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"I\",\nFontWeight->\"Bold\"]\
\)\!\(\*\nStyleBox[\":\",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"External\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\"loadings\",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"on\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\"the\",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"beam\",\nFontWeight->\"Bold\"]\)", 
         Spacer[65]}]}, {
      1 -> "\!\(\*\nStyleBox[\"On\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 0 -> 
       "\!\(\*\nStyleBox[\"off\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)"}}, {{
       Hold[$CellContext`opa2$$], 1, 
       Row[{"Types of Beam", 
         Spacer[85]}]}, {
      1 -> 
       "\!\(\*\nStyleBox[\"Cantilever\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 0 -> 
       "\!\(\*\nStyleBox[\"Simply\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"-\",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"Supported\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)"}}, {{
       Hold[$CellContext`pf$$], 0.4, 
       Row[{"Position of force [m]", 
         Spacer[60]}]}, 0, 1}, {{
       Hold[$CellContext`mf$$], 0.25, 
       Row[{
        "\!\(\*\nStyleBox[\"Magnitude\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\" \",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"of\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"force\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"[\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"kN\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"]\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 
         Spacer[39]}]}, 0, 0.5}, {{
       Hold[$CellContext`dirf$$], 120, 
       Row[{
        "\!\(\*\nStyleBox[\"Direction\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\" \",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"of\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"Force\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"[\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"\[Degree]\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"]\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 
         Spacer[58]}]}, 0, 360}, {{
       Hold[$CellContext`pm$$], 0.6, 
       Row[{
        "\!\(\*\nStyleBox[\"Position\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\
\(\*\nStyleBox[\" \",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"of\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"moment\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"[\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"m\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"]\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 
         Spacer[43]}]}, 0, 1}, {{
       Hold[$CellContext`mm$$], 0.25, 
       Row[{
        "\!\(\*\nStyleBox[\"Magnitude\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\" \",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"of\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"moment\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"[\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"kN\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"\[CenterDot]\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"m\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"]\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 
         Spacer[8]}]}, 0, 0.5}, {{
       Hold[$CellContext`dirm$$], 1, 
       Row[{
        "\!\(\*\nStyleBox[\"Direction\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\" \",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"of\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"Moment\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 
         Spacer[53]}]}, {1 -> "CCW", 0 -> "CW"}}, {{
       Hold[$CellContext`reac$$], 0, 
       Row[{"Reactive Force & Moment", 
         Spacer[26.5]}]}, {1 -> "On", 0 -> "Off"}}, {{
       Hold[$CellContext`step2$$], 0, 
       Row[{
        "\!\(\*\nStyleBox[\"Step\",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\
\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"II\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\":\",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"Internal\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\"forces\",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"in\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\"the\",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"beam\",\nFontWeight->\"Bold\"]\)", 
         Spacer[75]}]}, {
      1 -> "\!\(\*\nStyleBox[\"On\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 0 -> 
       "\!\(\*\nStyleBox[\"off\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)"}}, {{
       Hold[$CellContext`ps$$], 0.25, 
       Row[{"Position of section [m]", 
         Spacer[43]}]}, 0.01, 0.99}, {{
       Hold[$CellContext`int$$], 0, 
       Row[{"Internal Forces", 
         Spacer[85]}]}, {1 -> "On", 0 -> "Off"}}, {{
       Hold[$CellContext`step3$$], 0, 
       Row[{
        "\!\(\*\nStyleBox[\"Step\",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\
\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"III\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\":\",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"Internal\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\"force\",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"diagrams\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\"of\",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"the\",\nFontWeight->\"Bold\"]\)\!\(\
\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"beam\",\n\
FontWeight->\"Bold\"]\)", 
         Spacer[20]}]}, {
      1 -> "\!\(\*\nStyleBox[\"On\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 0 -> 
       "\!\(\*\nStyleBox[\"off\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)"}}, {{
       Hold[$CellContext`nd$$], 1, 
       Row[{"Normal Force Diagram", 
         Spacer[40]}]}, {1 -> "On", 0 -> "Off"}}, {{
       Hold[$CellContext`sd$$], 1, 
       Row[{"Shear Force Diagram", 
         Spacer[50]}]}, {1 -> "On", 0 -> "Off"}}, {{
       Hold[$CellContext`bd$$], 1, 
       Row[{"Bending Moment Diagram", 
         Spacer[20]}]}, {1 -> "On", 0 -> "Off"}}, {
      Hold[
       Item[
        Column[{
          Grid[{{
             Manipulate`Place[1]}, {
             Manipulate`Place[2]}, {
             PaneSelector[{1 -> Column[{
                  Row[{
                    Manipulate`Place[3]}], 
                  Row[{
                    Manipulate`Place[4]}], 
                  Row[{
                    Manipulate`Place[5]}], 
                  Row[{
                    Manipulate`Place[6]}], 
                  Row[{
                    Manipulate`Place[7]}], 
                  Row[{
                    Manipulate`Place[8]}], 
                  Row[{
                    Manipulate`Place[9]}], 
                  Row[{
                    Manipulate`Place[10]}], 
                  Row[{
                    Dynamic[
                    
                    If[$CellContext`reac$$ $CellContext`step1$$ == 
                    1, $CellContext`temp1, 
                    Invisible[$CellContext`temp]]]}]}]}, 
              Dynamic[$CellContext`step1$$]]}, {
             
             Row[{"---------------------------------------------------------"}\
]}, {
             Manipulate`Place[11]}, {
             PaneSelector[{
               Column[{
                 Row[{
                   Manipulate`Place[12]}], 
                 Row[{
                   Manipulate`Place[13]}], 
                 Row[{
                   Dynamic[
                    If[$CellContext`int$$ == 1, $CellContext`temp2, 
                    Invisible[$CellContext`temp]]]}]}]}, 
              Dynamic[$CellContext`step2$$]]}, {
             
             Row[{"---------------------------------------------------------"}\
]}, {
             Manipulate`Place[14]}, {
             PaneSelector[{
               Column[{
                 Row[{
                   Manipulate`Place[15]}], 
                 Row[{
                   Manipulate`Place[16]}], 
                 Row[{
                   Manipulate`Place[17]}]}]}, 
              Dynamic[$CellContext`step3$$]]}}, Alignment -> Left, 
           Spacings -> {Automatic, 1.5}]}]]], 
      Manipulate`Dump`ThisIsNotAControl}}, Typeset`size$$ = {
    760., {266., 272.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`opa1$8002$$ = 
    False, $CellContext`step1$8003$$ = False, $CellContext`opa2$8004$$ = 
    False, $CellContext`pf$8005$$ = 0, $CellContext`mf$8006$$ = 
    0, $CellContext`dirf$8007$$ = 0, $CellContext`pm$8008$$ = 
    0, $CellContext`mm$8009$$ = 0, $CellContext`dirm$8010$$ = 
    False, $CellContext`reac$8011$$ = False, $CellContext`step2$8012$$ = 
    False, $CellContext`ps$8013$$ = 0, $CellContext`int$8014$$ = 
    False, $CellContext`step3$8015$$ = False, $CellContext`nd$8016$$ = 
    False, $CellContext`sd$8017$$ = False, $CellContext`bd$8018$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`bd$$ = 1, $CellContext`dirf$$ = 
        120, $CellContext`dirm$$ = 1, $CellContext`int$$ = 
        0, $CellContext`mf$$ = 0.25, $CellContext`mm$$ = 
        0.25, $CellContext`nd$$ = 1, $CellContext`opa1$$ = 
        0, $CellContext`opa2$$ = 1, $CellContext`pf$$ = 
        0.4, $CellContext`pm$$ = 0.6, $CellContext`ps$$ = 
        0.25, $CellContext`reac$$ = 0, $CellContext`sd$$ = 
        1, $CellContext`step1$$ = 0, $CellContext`step2$$ = 
        0, $CellContext`step3$$ = 0}, "ControllerVariables" :> {
        Hold[$CellContext`opa1$$, $CellContext`opa1$8002$$, False], 
        Hold[$CellContext`step1$$, $CellContext`step1$8003$$, False], 
        Hold[$CellContext`opa2$$, $CellContext`opa2$8004$$, False], 
        Hold[$CellContext`pf$$, $CellContext`pf$8005$$, 0], 
        Hold[$CellContext`mf$$, $CellContext`mf$8006$$, 0], 
        Hold[$CellContext`dirf$$, $CellContext`dirf$8007$$, 0], 
        Hold[$CellContext`pm$$, $CellContext`pm$8008$$, 0], 
        Hold[$CellContext`mm$$, $CellContext`mm$8009$$, 0], 
        Hold[$CellContext`dirm$$, $CellContext`dirm$8010$$, False], 
        Hold[$CellContext`reac$$, $CellContext`reac$8011$$, False], 
        Hold[$CellContext`step2$$, $CellContext`step2$8012$$, False], 
        Hold[$CellContext`ps$$, $CellContext`ps$8013$$, 0], 
        Hold[$CellContext`int$$, $CellContext`int$8014$$, False], 
        Hold[$CellContext`step3$$, $CellContext`step3$8015$$, False], 
        Hold[$CellContext`nd$$, $CellContext`nd$8016$$, False], 
        Hold[$CellContext`sd$$, $CellContext`sd$8017$$, False], 
        Hold[$CellContext`bd$$, $CellContext`bd$8018$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`size$, $CellContext`alfa$, $CellContext`L$, \
$CellContext`W$, 
         Null$, $CellContext`pa$, $CellContext`pb$, $CellContext`pau$, \
$CellContext`pad$, $CellContext`pina1$, $CellContext`pina2$, \
$CellContext`pina3$, $CellContext`pinal$, $CellContext`pinar$, \
$CellContext`robr$, $CellContext`robc$, $CellContext`rolbr$, \
$CellContext`rolbl$, $CellContext`fe$, $CellContext`fi$, $CellContext`fx$, \
$CellContext`fy$, $CellContext`mp$, $CellContext`sitaie$, \
$CellContext`sitai$, $CellContext`sitae$, $CellContext`rm$, $CellContext`mi$, \
$CellContext`me$, $CellContext`cAx$, $CellContext`cAy$, $CellContext`cFm$, \
$CellContext`cMm$, $CellContext`cMA$, $CellContext`rMA$, \
$CellContext`sitaMA$, $CellContext`sitaMAi$, $CellContext`sitaMAe$, \
$CellContext`mAi$, $CellContext`mAe$, $CellContext`sAx$, $CellContext`sAy$, \
$CellContext`sBy$, $CellContext`cifx$, $CellContext`cify$, \
$CellContext`cifMs$, $CellContext`cimMs$, $CellContext`ciMs$, \
$CellContext`rMs$, $CellContext`csitaiMs$, $CellContext`csitaiMsi$, \
$CellContext`csitaiMse$, $CellContext`csitaiMsid$, $CellContext`csitaiMsed$, \
$CellContext`cmsi$, $CellContext`cmse$, $CellContext`cmsid$, \
$CellContext`cmsed$, $CellContext`sifx$, $CellContext`sify$, \
$CellContext`siMs$, $CellContext`ssitaiMs$, $CellContext`ssitaiMsi$, \
$CellContext`ssitaiMse$, $CellContext`ssitaiMsid$, $CellContext`ssitaiMsed$, \
$CellContext`smsi$, $CellContext`smse$, $CellContext`smsid$, \
$CellContext`smsed$, $CellContext`sopa1$, $CellContext`sopa2$, \
$CellContext`sopa3$, $CellContext`psu$, $CellContext`psd$, \
$CellContext`cxfx$, $CellContext`cxfy$, $CellContext`cxMs$, \
$CellContext`sxfx$, $CellContext`sxfy$, $CellContext`sxMs$, \
$CellContext`normal$, $CellContext`shear$, $CellContext`moment$, \
$CellContext`x$, $CellContext`csru$, $CellContext`csrd$, $CellContext`csr$, \
$CellContext`ssru$, $CellContext`ssrd$, $CellContext`ssr$, \
$CellContext`cmru$, $CellContext`cmrd$, $CellContext`cmr$, \
$CellContext`smru$, $CellContext`smrd$, $CellContext`smr$, \
$CellContext`dwf0$, $CellContext`dwf1$, $CellContext`dwf2$, \
$CellContext`dwf3$, $CellContext`dwf4$, $CellContext`dwf5$, \
$CellContext`dwf6$, $CellContext`dwf7$, $CellContext`dwf8$, \
$CellContext`dwf9$, $CellContext`dwf10$, $CellContext`dwf11$, \
$CellContext`dwf12$, $CellContext`dwf13$, $CellContext`dwf14$, \
$CellContext`dwf15$, $CellContext`dwf16$, $CellContext`dwf17$}, \
$CellContext`size$ = 1; $CellContext`alfa$ = ($CellContext`dirf$$/180) Pi; 
        If[$CellContext`dirm$$ == 
          1, $CellContext`cMm$ = $CellContext`mm$$, $CellContext`cMm$ = \
-$CellContext`mm$$]; $CellContext`L$ = 1; $CellContext`W$ = 
         0.1 $CellContext`L$; $CellContext`pa$ = {0, 
          0}; $CellContext`pb$ = {$CellContext`L$, 
           0}; $CellContext`pau$ = $CellContext`pa$ + {
           0, $CellContext`W$}; $CellContext`pad$ = $CellContext`pa$ + {
           0, -$CellContext`W$}; $CellContext`pina1$ = $CellContext`pa$; \
$CellContext`pina2$ = $CellContext`pa$ + {(-$CellContext`W$)/
            1.5, (-$CellContext`W$)/
            1.1}; $CellContext`pina3$ = $CellContext`pa$ + {$CellContext`W$/
            1.5, (-$CellContext`W$)/
            1.1}; $CellContext`pinal$ = $CellContext`pina2$ + \
{(-$CellContext`W$)/4, 
            0}; $CellContext`pinar$ = $CellContext`pina3$ + {$CellContext`W$/
            4, 0}; $CellContext`robr$ = (Abs[
             Part[$CellContext`pinal$, 2]] - $CellContext`W$/2)/
          2; $CellContext`robc$ = {$CellContext`L$, -$CellContext`robr$ - \
$CellContext`W$/2} + {(-$CellContext`robr$)/2, 
            0}; $CellContext`rolbr$ = $CellContext`pinar$ + {$CellContext`L$, 
            0} + {(-$CellContext`robr$)/2, 
            0}; $CellContext`rolbl$ = $CellContext`pinal$ + {$CellContext`L$, 
            0} + {(-$CellContext`robr$)/2, 
            0}; $CellContext`fe$ = {$CellContext`pf$$ $CellContext`L$, 
           0}; $CellContext`fi$ = {$CellContext`mf$$ 
            Cos[$CellContext`alfa$], $CellContext`mf$$ 
            Sin[$CellContext`alfa$]} + $CellContext`fe$; $CellContext`fx$ = {
          Part[$CellContext`fe$, 1] - Part[$CellContext`fi$, 1], 
           0}; $CellContext`fy$ = {
          0, Part[$CellContext`fe$, 2] - 
           Part[$CellContext`fi$, 2]}; $CellContext`mp$ = {$CellContext`pm$$, 
           0}; $CellContext`sitaie$ = ($CellContext`cMm$ 1.8) 
          Pi; $CellContext`sitai$ = (-$CellContext`sitaie$)/
          2; $CellContext`sitae$ = $CellContext`sitaie$/2; $CellContext`rm$ = 
         1.2 $CellContext`W$; $CellContext`mi$ = {$CellContext`rm$ 
            Cos[$CellContext`sitae$ - $CellContext`sitaie$ 
              0.1], $CellContext`rm$ 
            Sin[$CellContext`sitae$ - $CellContext`sitaie$ 
              0.1]} + $CellContext`mp$; $CellContext`me$ = {$CellContext`rm$ 
            Cos[$CellContext`sitae$], $CellContext`rm$ 
            Sin[$CellContext`sitae$]} + $CellContext`mp$; $CellContext`cAx$ = \
-$CellContext`fx$; $CellContext`cAy$ = -$CellContext`fy$; $CellContext`cFm$ = 
         Part[$CellContext`fy$, 
            2] $CellContext`pf$$; $CellContext`cMA$ = $CellContext`cFm$ + \
$CellContext`cMm$; $CellContext`rMA$ = $CellContext`rm$; $CellContext`sitaMA$ = \
($CellContext`cMA$ 1.8) Pi; $CellContext`sitaMAi$ = 
         Pi + $CellContext`sitaMA$/2; $CellContext`sitaMAe$ = 
         Pi - $CellContext`sitaMA$/
          2; $CellContext`mAi$ = {$CellContext`rMA$ 
            Cos[$CellContext`sitaMAe$ + ($CellContext`sitaMAe$ - \
$CellContext`sitaMAi$) 0.1], $CellContext`rMA$ 
            Sin[$CellContext`sitaMAe$ + ($CellContext`sitaMAe$ - \
$CellContext`sitaMAi$) 
               0.1]} + $CellContext`pa$; $CellContext`mAe$ = \
{$CellContext`rMA$ Cos[$CellContext`sitaMAe$], $CellContext`rMA$ 
            Sin[$CellContext`sitaMAe$]} + $CellContext`pa$; $CellContext`sAx$ = \
-$CellContext`fx$; $CellContext`sBy$ = {
          0, -$CellContext`cMm$ - 
           Part[$CellContext`fy$, 
             2] ($CellContext`pf$$/$CellContext`L$)}; $CellContext`sAy$ = \
-$CellContext`sBy$ - $CellContext`fy$; $CellContext`cifx$ = {
           
           Norm[-$CellContext`cAx$ - $CellContext`fx$ 
            UnitStep[$CellContext`ps$$ - $CellContext`pf$$]], 
           0}; $CellContext`cify$ = {
          0, -Norm[-$CellContext`cAy$ - $CellContext`fy$ 
             UnitStep[$CellContext`ps$$ - $CellContext`pf$$]]}; \
$CellContext`ciMs$ = 
         Abs[$CellContext`cMA$ - $CellContext`cMm$ 
           UnitStep[$CellContext`ps$$ - $CellContext`pm$$] + 
           Part[$CellContext`cAy$, 2] $CellContext`ps$$ + (
             Part[$CellContext`fy$, 
               2] ($CellContext`ps$$ - $CellContext`pf$$)) 
            UnitStep[$CellContext`ps$$ - $CellContext`pf$$]]; 
        If[Norm[$CellContext`ciMs$] <= 0.0001, $CellContext`ciMs$ = 
          0]; $CellContext`rMs$ = $CellContext`rm$; $CellContext`csitaiMs$ = \
($CellContext`ciMs$ 1.8) 
          Pi; $CellContext`csitaiMsi$ = (-$CellContext`csitaiMs$)/
          2; $CellContext`csitaiMse$ = $CellContext`csitaiMs$/
          2; $CellContext`csitaiMsid$ = 
         Pi + $CellContext`csitaiMs$/2; $CellContext`csitaiMsed$ = 
         Pi - $CellContext`csitaiMs$/
          2; $CellContext`cmsi$ = {$CellContext`rMs$ 
           Cos[$CellContext`csitaiMse$ + ($CellContext`csitaiMse$ - \
$CellContext`csitaiMsi$) 0.1], $CellContext`rMs$ 
           Sin[$CellContext`csitaiMse$ + ($CellContext`csitaiMse$ - \
$CellContext`csitaiMsi$) 0.1]}; $CellContext`cmse$ = {$CellContext`rMs$ 
           Cos[$CellContext`csitaiMse$], $CellContext`rMs$ 
           Sin[$CellContext`csitaiMse$]}; $CellContext`cmsid$ = \
{$CellContext`rMs$ 
           Cos[$CellContext`csitaiMsed$ + ($CellContext`csitaiMsed$ - \
$CellContext`csitaiMsid$) 0.1], $CellContext`rMs$ 
           Sin[$CellContext`csitaiMsed$ + ($CellContext`csitaiMsed$ - \
$CellContext`csitaiMsid$) 0.1]}; $CellContext`cmsed$ = {$CellContext`rMs$ 
           Cos[$CellContext`csitaiMsed$], $CellContext`rMs$ 
           Sin[$CellContext`csitaiMsed$]}; $CellContext`sifx$ = {
           
           Norm[-$CellContext`sAx$ - $CellContext`fx$ 
            UnitStep[$CellContext`ps$$ - $CellContext`pf$$]], 
           0}; $CellContext`sify$ = {
          0, -Norm[-$CellContext`sAy$ - $CellContext`fy$ 
             UnitStep[$CellContext`ps$$ - $CellContext`pf$$]]}; \
$CellContext`siMs$ = 
         Abs[Part[$CellContext`sAy$, 2] $CellContext`ps$$ + (
             Part[$CellContext`fy$, 
               2] ($CellContext`ps$$ - $CellContext`pf$$)) 
            UnitStep[$CellContext`ps$$ - $CellContext`pf$$] - \
$CellContext`cMm$ UnitStep[$CellContext`ps$$ - $CellContext`pm$$]]; 
        If[Norm[$CellContext`siMs$] <= 0.0001, $CellContext`siMs$ = 
          0]; $CellContext`rMs$ = $CellContext`rm$; $CellContext`ssitaiMs$ = \
($CellContext`siMs$ 1.8) 
          Pi; $CellContext`ssitaiMsi$ = (-$CellContext`ssitaiMs$)/
          2; $CellContext`ssitaiMse$ = $CellContext`ssitaiMs$/
          2; $CellContext`ssitaiMsid$ = 
         Pi + $CellContext`ssitaiMs$/2; $CellContext`ssitaiMsed$ = 
         Pi - $CellContext`ssitaiMs$/
          2; $CellContext`smsi$ = {$CellContext`rMs$ 
           Cos[$CellContext`ssitaiMse$ - $CellContext`ssitaiMs$ 
             0.1], $CellContext`rMs$ 
           Sin[$CellContext`ssitaiMse$ - $CellContext`ssitaiMs$ 
             0.1]}; $CellContext`smse$ = {$CellContext`rMs$ 
           Cos[$CellContext`ssitaiMse$], $CellContext`rMs$ 
           Sin[$CellContext`ssitaiMse$]}; $CellContext`smsid$ = \
{$CellContext`rMs$ 
           Cos[$CellContext`ssitaiMsed$ + $CellContext`ssitaiMs$ 
              0.1], $CellContext`rMs$ 
           Sin[$CellContext`ssitaiMsed$ + $CellContext`ssitaiMs$ 
              0.1]}; $CellContext`smsed$ = {$CellContext`rMs$ 
           Cos[$CellContext`ssitaiMsed$], $CellContext`rMs$ 
           Sin[$CellContext`ssitaiMsed$]}; $CellContext`cxfx$[
           Pattern[$CellContext`x$, 
            Blank[]]] := -Part[$CellContext`cAx$, 1] - 
          UnitStep[$CellContext`x$ - $CellContext`pf$$] 
          Part[$CellContext`fx$, 1]; $CellContext`cxfy$[
           Pattern[$CellContext`x$, 
            Blank[]]] := -Part[$CellContext`cAy$, 2] - 
          Part[$CellContext`fy$, 2] 
          UnitStep[$CellContext`x$ - $CellContext`pf$$]; $CellContext`cxMs$[
           Pattern[$CellContext`x$, 
            Blank[]]] := $CellContext`cMA$ - 
          UnitStep[$CellContext`x$ - $CellContext`pm$$] $CellContext`cMm$ + 
          Part[$CellContext`cAy$, 2] $CellContext`x$ + (
            Part[$CellContext`fy$, 2] ($CellContext`x$ - $CellContext`pf$$)) 
           UnitStep[$CellContext`x$ - $CellContext`pf$$]; $CellContext`sxfx$[
           Pattern[$CellContext`x$, 
            Blank[]]] := -Part[$CellContext`sAx$, 1] - 
          UnitStep[$CellContext`x$ - $CellContext`pf$$] 
          Part[$CellContext`fx$, 1]; $CellContext`sxfy$[
           Pattern[$CellContext`x$, 
            Blank[]]] := -Part[$CellContext`sAy$, 2] - 
          UnitStep[$CellContext`x$ - $CellContext`pf$$] 
          Part[$CellContext`fy$, 2]; $CellContext`sxMs$[
           Pattern[$CellContext`x$, 
            Blank[]]] := 
         Part[$CellContext`sAy$, 2] $CellContext`x$ + (
            Part[$CellContext`fy$, 2] ($CellContext`x$ - $CellContext`pf$$)) 
           UnitStep[$CellContext`x$ - $CellContext`pf$$] - 
          UnitStep[$CellContext`x$ - $CellContext`pm$$] $CellContext`cMm$; \
$CellContext`csr$ = Norm[$CellContext`fy$]; $CellContext`ssr$ = 
         Norm[$CellContext`sAy$] + Norm[$CellContext`fy$]; 
        If[Abs[$CellContext`cMA$] > Abs[$CellContext`cMm$], $CellContext`cmr$ = 
          Abs[$CellContext`cMA$], $CellContext`cmr$ = Abs[$CellContext`cMm$]]; 
        If[Sign[$CellContext`cMm$] Sign[
             Part[$CellContext`sBy$, 2]] >= 0, $CellContext`smr$ = 
          Abs[$CellContext`cMm$] + 
           Abs[Part[$CellContext`sBy$, 
               2] ($CellContext`L$ - $CellContext`pf$$)], $CellContext`smr$ = 
          Abs[Abs[$CellContext`cMm$] - Abs[
            Part[$CellContext`sBy$, 
               2] ($CellContext`L$ - $CellContext`pm$$)]]]; \
$CellContext`datanormal = 
         Table[{$CellContext`ps$$, $CellContext`i}, {$CellContext`i, -
            Norm[$CellContext`fx$], 
            Norm[$CellContext`fx$], Norm[$CellContext`fx$]/10}]; 
        If[$CellContext`opa2$$ == 1, $CellContext`normal$ = Labeled[
            Plot[
             $CellContext`cxfx$[$CellContext`x$], {$CellContext`x$, 
              0, $CellContext`L$}, Frame -> True, 
             FrameLabel -> {
              "\!\(\*\nStyleBox[\"x\",\nFontFamily->\"Arial\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"[\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"m\",\n\
FontFamily->\"Arial\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"]\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\
\nFontColor->RGBColor[0., 0., 0.]]\)", 
               "\!\(\*\nStyleBox[\"N\",\nFontFamily->\"Arial\",\nFontWeight->\
\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"[\",\n\
FontFamily->\"Arial\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"kN\",\nFontFamily->\"Arial\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"]\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)"}, 
             PlotRange -> {(-1.1) Norm[$CellContext`fx$], 1.1 
               Norm[$CellContext`fx$]}, ImageMargins -> 5, ImageSize -> 350, 
             AspectRatio -> 0.35, AxesOrigin -> {0, 0}, Filling -> Axis, 
             FillingStyle -> Lighter[Red, 0.8], Epilog -> {
               Point[$CellContext`datanormal]}], 
            Text[
             Style["Normal Force", Bold, 11]], {{Top, Center}}, 
            Spacings -> {Automatic, -0.35}], $CellContext`normal$ = Labeled[
            Plot[
             $CellContext`sxfx$[$CellContext`x$], {$CellContext`x$, 
              0, $CellContext`L$}, Frame -> True, 
             FrameLabel -> {
              "\!\(\*\nStyleBox[\"x\",\nFontFamily->\"Arial\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"[\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"m\",\n\
FontFamily->\"Arial\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"]\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\
\nFontColor->RGBColor[0., 0., 0.]]\)", 
               "\!\(\*\nStyleBox[\"N\",\nFontFamily->\"Arial\",\nFontWeight->\
\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"[\",\n\
FontFamily->\"Arial\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"kN\",\nFontFamily->\"Arial\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"]\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)"}, 
             PlotRange -> {(-1.1) Norm[$CellContext`fx$], 1.1 
               Norm[$CellContext`fx$]}, ImageMargins -> 5, ImageSize -> 350, 
             AspectRatio -> 0.35, AxesOrigin -> {0, 0}, Filling -> Axis, 
             FillingStyle -> Lighter[Red, 0.8], Epilog -> {
               Point[$CellContext`datanormal]}], 
            Text[
             Style["Normal Force", Bold, 11]], {{Top, Center}}, 
            Spacings -> {Automatic, -0.35}]]; $CellContext`datashearcant = 
         Table[{$CellContext`ps$$, $CellContext`i}, {$CellContext`i, \
-$CellContext`csr$, $CellContext`csr$, $CellContext`csr$/
            10}]; $CellContext`datashearsimp = 
         Table[{$CellContext`ps$$, $CellContext`i}, {$CellContext`i, \
-$CellContext`ssr$, $CellContext`ssr$, $CellContext`ssr$/10}]; 
        If[$CellContext`opa2$$ == 1, $CellContext`shear$ = Labeled[
            
            Plot[-$CellContext`cxfy$[$CellContext`x$], {$CellContext`x$, 
              0, $CellContext`L$}, Frame -> True, 
             FrameLabel -> {
              "\!\(\*\nStyleBox[\"x\",\nFontFamily->\"Arial\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"[\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"m\",\n\
FontFamily->\"Arial\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"]\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\
\nFontColor->RGBColor[0., 0., 0.]]\)", 
               "\!\(\*\nStyleBox[\"V\",\nFontFamily->\"Arial\",\nFontWeight->\
\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"[\",\n\
FontFamily->\"Arial\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"kN\",\nFontFamily->\"Arial\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"]\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)"}, 
             PlotRange -> {(-1.1) $CellContext`csr$, 1.1 $CellContext`csr$}, 
             ImageMargins -> 5, ImageSize -> 350, AspectRatio -> 0.35, 
             FrameTicksStyle -> Directive[10], AxesOrigin -> {0, 0}, Filling -> 
             Axis, FillingStyle -> Lighter[Green, 0.8], Epilog -> {
               Point[$CellContext`datashearcant]}], 
            Text[
             Style["Shear force", Bold, 11]], {{Top, Center}}, 
            Spacings -> {Automatic, -0.35}], $CellContext`shear$ = Labeled[
            
            Plot[-$CellContext`sxfy$[$CellContext`x$], {$CellContext`x$, 
              0, $CellContext`L$}, Frame -> True, 
             FrameLabel -> {
              "\!\(\*\nStyleBox[\"x\",\nFontFamily->\"Arial\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"[\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"m\",\n\
FontFamily->\"Arial\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"]\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\
\nFontColor->RGBColor[0., 0., 0.]]\)", 
               "\!\(\*\nStyleBox[\"V\",\nFontFamily->\"Arial\",\nFontWeight->\
\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"[\",\n\
FontFamily->\"Arial\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"kN\",\nFontFamily->\"Arial\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"]\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)"}, 
             PlotRange -> {(-1.1) $CellContext`ssr$, 1.1 $CellContext`ssr$}, 
             ImageMargins -> 5, ImageSize -> 350, AspectRatio -> 0.35, 
             FrameTicksStyle -> Directive[10], AxesOrigin -> {0, 0}, Filling -> 
             Axis, FillingStyle -> Lighter[Green, 0.8], Epilog -> {
               Point[$CellContext`datashearsimp]}], 
            Text[
             Style["Shear Force", Bold, 11]], {{Top, Center}}, 
            Spacings -> {Automatic, -0.35}]]; $CellContext`datamomentcant = 
         Table[{$CellContext`ps$$, $CellContext`i}, {$CellContext`i, \
-$CellContext`cmr$, $CellContext`cmr$, $CellContext`cmr$/
            10}]; $CellContext`datamomentsimp = 
         Table[{$CellContext`ps$$, $CellContext`i}, {$CellContext`i, \
-$CellContext`smr$, $CellContext`smr$, $CellContext`smr$/10}]; 
        If[$CellContext`opa2$$ == 1, $CellContext`moment$ = Labeled[
            Plot[
             $CellContext`cxMs$[$CellContext`x$], {$CellContext`x$, 
              0, $CellContext`L$}, Frame -> True, 
             FrameLabel -> {
              "\!\(\*\nStyleBox[\"x\",\nFontFamily->\"Arial\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"[\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"m\",\n\
FontFamily->\"Arial\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"]\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\
\nFontColor->RGBColor[0., 0., 0.]]\)", 
               "\!\(\*\nStyleBox[\"M\",\nFontFamily->\"Arial\",\nFontWeight->\
\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"[\",\n\
FontFamily->\"Arial\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"kN\",\nFontFamily->\"Arial\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"\
\[CenterDot]\",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\"]\)\!\(\*\n\
StyleBox[\"m\",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"]\",\n\
FontFamily->\"Arial\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)"}, PlotRange -> {(-1.1) $CellContext`cmr$, 1.1 $CellContext`cmr$}, 
             ImageMargins -> 5, ImageSize -> 350, AspectRatio -> 0.35, 
             FrameTicksStyle -> Directive[10], AxesOrigin -> {0, 0}, Filling -> 
             Axis, FillingStyle -> Lighter[Blue, 0.8], Epilog -> {
               Point[$CellContext`datamomentcant]}], 
            Text[
             Style["Bending Moment", Bold, 11]], {{Top, Center}}, 
            Spacings -> {Automatic, -0.35}], $CellContext`moment$ = Labeled[
            Plot[
             $CellContext`sxMs$[$CellContext`x$], {$CellContext`x$, 
              0, $CellContext`L$}, Frame -> True, 
             FrameLabel -> {
              "\!\(\*\nStyleBox[\"x\",\nFontFamily->\"Arial\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"[\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"m\",\n\
FontFamily->\"Arial\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"]\",\nFontFamily->\"Arial\",\nFontWeight->\"Plain\",\
\nFontColor->RGBColor[0., 0., 0.]]\)", 
               "\!\(\*\nStyleBox[\"M\",\nFontFamily->\"Arial\",\nFontWeight->\
\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"[\",\n\
FontFamily->\"Arial\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"kN\",\nFontFamily->\"Arial\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"\
\[CenterDot]\",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\"]\)\!\(\*\n\
StyleBox[\"m\",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"]\",\n\
FontFamily->\"Arial\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)"}, ImageMargins -> 5, ImageSize -> 350, AspectRatio -> 0.35, 
             FrameTicksStyle -> Directive[10], AxesOrigin -> {0, 0}, Filling -> 
             Axis, FillingStyle -> Lighter[Blue, 0.8], Epilog -> {
               Point[$CellContext`datamomentsimp]}], 
            Text[
             Style["Bending Moment", Bold, 11]], {{Top, Center}}, 
            Spacings -> {Automatic, -0.35}]]; 
        If[$CellContext`step1$$ == 1, $CellContext`sopa1$ = 
          1, $CellContext`sopa1$ = 0]; 
        If[$CellContext`step2$$ == 1, $CellContext`sopa2$ = 
          1, $CellContext`sopa2$ = 0]; 
        If[$CellContext`step3$$ == 1, $CellContext`sopa3$ = 
          1, $CellContext`sopa3$ = 
          0]; $CellContext`psu$ = {$CellContext`ps$$, 0} + {
           0, 2 $CellContext`W$}; $CellContext`psd$ = {$CellContext`ps$$, 
            0} + {0, (-2) $CellContext`W$}; 
        If[$CellContext`opa2$$ == 1, $CellContext`temp1 = 
          Row[{"\!\(\*\nStyleBox[FormBox[SubscriptBox[\"M\", \"A\"],\n  \
TraditionalForm],\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 1.]]\)\
\!\(\*\nStyleBox[\"  \",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
1.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 1.]]\)", 
             NumberForm[-$CellContext`cMA$, {4, 3}], 
             Spacer[2], 
             "\!\(\*\nStyleBox[\"kN\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"\[CenterDot]\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"m\
\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)", 
             Spacer[15], 
             "\!\(\*\nStyleBox[FormBox[SubscriptBox[\"A\", \"x\"],\n  \
TraditionalForm],\nFontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]]\)\
\!\(\*\nStyleBox[\" \",\nFontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., \
0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 1.]]\)", 
             NumberForm[
              Part[$CellContext`cAx$, 1], {4, 3}], 
             Spacer[2], 
             "\!\(\*\nStyleBox[\"kN\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)", 
             Spacer[15], 
             "\!\(\*\nStyleBox[FormBox[SubscriptBox[\"A\", \"y\"],\n  \
TraditionalForm],\nFontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]]\)\
\!\(\*\nStyleBox[\" \",\nFontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., \
0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\) ", 
             NumberForm[
              Part[$CellContext`cAy$, 2], {4, 3}], 
             Spacer[2], 
             "\!\(\*\nStyleBox[\"kN\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)"}]]; 
        If[$CellContext`opa2$$ == 0, $CellContext`temp1 = 
          Row[{"\!\(\*\nStyleBox[FormBox[SubscriptBox[\"A\", \"x\"],\n  \
TraditionalForm],\nFontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]]\)\
\!\(\*\nStyleBox[\" \",\nFontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., \
0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\) ", 
             NumberForm[
              Part[$CellContext`sAx$, 1], {4, 3}], 
             Spacer[2], 
             "\!\(\*\nStyleBox[\"kN\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)", 
             Spacer[15], 
             "\!\(\*\nStyleBox[FormBox[SubscriptBox[\"A\", \"y\"],\n  \
TraditionalForm],\nFontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]]\)\
\!\(\*\nStyleBox[\" \",\nFontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., \
0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\) ", 
             NumberForm[
              Part[$CellContext`sAy$, 2], {4, 3}], 
             Spacer[2], 
             "\!\(\*\nStyleBox[\"kN\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)", 
             Spacer[15], 
             "\!\(\*\nStyleBox[FormBox[SubscriptBox[\"B\", \"y\"],\n  \
TraditionalForm],\nFontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]]\)\
\!\(\*\nStyleBox[\" \",\nFontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., \
0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\) ", 
             NumberForm[
              Part[$CellContext`sBy$, 2], {4, 3}], 
             Spacer[2], 
             "\!\(\*\nStyleBox[\"kN\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)"}]]; 
        If[$CellContext`opa2$$ == 1, $CellContext`temp2 = 
          Row[{"\!\(\*\nStyleBox[FormBox[SubscriptBox[\"M\", \"a\"],\n  \
TraditionalForm],\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)\!\(\*\n\
StyleBox[\"  \",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)\!\(\*\n\
StyleBox[\"=\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)\!\(\*\n\
StyleBox[\" \",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 1.]]\)", 
             
             NumberForm[$CellContext`cMA$ - $CellContext`cMm$ 
              UnitStep[$CellContext`ps$$ - $CellContext`pm$$] + 
              Part[$CellContext`cAy$, 2] $CellContext`ps$$ + (
                Part[$CellContext`fy$, 
                  2] ($CellContext`ps$$ - $CellContext`pf$$)) 
               UnitStep[$CellContext`ps$$ - $CellContext`pf$$], {4, 3}], 
             Spacer[2], 
             "\!\(\*\nStyleBox[\"kN\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)\!\(\*\n\
StyleBox[\"\[CenterDot]\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)\!\(\*\n\
StyleBox[\"m\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)", 
             Spacer[15], 
             "\!\(\*\nStyleBox[FormBox[SubscriptBox[\"N\", \"a\"],\n  \
TraditionalForm],\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\
\!\(\*\nStyleBox[\" \",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 1.]]\)", 
             
             NumberForm[-Part[$CellContext`cAx$, 1] - 
              Part[$CellContext`fx$, 1] 
              UnitStep[$CellContext`ps$$ - $CellContext`pf$$], {4, 3}], 
             Spacer[2], 
             "\!\(\*\nStyleBox[\"kN\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 
             Spacer[15], 
             "\!\(\*\nStyleBox[FormBox[SubscriptBox[\"V\", \"a\"],\n  \
TraditionalForm],\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\
\!\(\*\nStyleBox[\" \",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\) ", 
             NumberForm[
             Part[$CellContext`cAy$, 2] + 
              Part[$CellContext`fy$, 2] 
               UnitStep[$CellContext`ps$$ - $CellContext`pf$$], {4, 3}], 
             Spacer[2], 
             "\!\(\*\nStyleBox[\"kN\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)"}]]; 
        If[$CellContext`opa2$$ == 0, $CellContext`temp2 = 
          Row[{"\!\(\*\nStyleBox[FormBox[SubscriptBox[\"M\", \"a\"],\n  \
TraditionalForm],\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)\!\(\*\n\
StyleBox[\"  \",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)\!\(\*\n\
StyleBox[\"=\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)\!\(\*\n\
StyleBox[\" \",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 1.]]\)", 
             NumberForm[
             Part[$CellContext`sAy$, 2] $CellContext`ps$$ + (
                Part[$CellContext`fy$, 
                  2] ($CellContext`ps$$ - $CellContext`pf$$)) 
               UnitStep[$CellContext`ps$$ - $CellContext`pf$$] - \
$CellContext`cMm$ UnitStep[$CellContext`ps$$ - $CellContext`pm$$], {4, 3}], 
             Spacer[2], 
             "\!\(\*\nStyleBox[\"kN\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)\!\(\*\n\
StyleBox[\"\[CenterDot]\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)\!\(\*\n\
StyleBox[\"m\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)", 
             Spacer[15], 
             "\!\(\*\nStyleBox[FormBox[SubscriptBox[\"N\", \"a\"],\n  \
TraditionalForm],\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\
\!\(\*\nStyleBox[\" \",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 1.]]\)", 
             
             NumberForm[-Part[$CellContext`sAx$, 1] - 
              Part[$CellContext`fx$, 1] 
              UnitStep[$CellContext`ps$$ - $CellContext`pf$$], {4, 3}], 
             Spacer[2], 
             "\!\(\*\nStyleBox[\"kN\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 
             Spacer[15], 
             "\!\(\*\nStyleBox[FormBox[SubscriptBox[\"V\", \"a\"],\n  \
TraditionalForm],\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\
\!\(\*\nStyleBox[\" \",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\) ", 
             NumberForm[
             Part[$CellContext`sAy$, 2] + 
              Part[$CellContext`fy$, 2] 
               UnitStep[$CellContext`ps$$ - $CellContext`pf$$], {4, 3}], 
             Spacer[2], 
             "\!\(\*\nStyleBox[\"kN\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)"}]]; 
        If[$CellContext`step1$$ == 0, $CellContext`reac$$ = 0]; 
        If[$CellContext`step2$$ == 0, $CellContext`int$$ = 0]; 
        If[$CellContext`step2$$ == 1, $CellContext`reac$$ = 1]; 
        If[$CellContext`step2$$ == 1, $CellContext`step1$$ = 1]; 
        If[$CellContext`step3$$ == 1, $CellContext`int$$ = 1]; 
        If[$CellContext`step3$$ == 1, $CellContext`reac$$ = 1]; 
        If[$CellContext`step3$$ == 1, $CellContext`step1$$ = 1]; 
        If[$CellContext`step3$$ == 1, $CellContext`step2$$ = 1]; Row[{
           Item[$CellContext`dwf0$ = {
               Opacity[$CellContext`opa1$$], 
               Dashing[{}], 
               Thickness[0.001], 
               Arrowheads[0.02], 
               
               Arrow[{{-$CellContext`size$, 0}, {
                 1.15 $CellContext`size$, 0}}], 
               
               Arrow[{{0, (-0.45) $CellContext`size$}, {
                 0, 0.45 $CellContext`size$}}], 
               Text[
               "\!\(\*\nStyleBox[\"x\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {1.2 $CellContext`size$, 0}], 
               Text[
               "\!\(\*\nStyleBox[\"y\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {(-0.05) $CellContext`size$, 
                 0.45 $CellContext`size$}]}; $CellContext`dwf1$ = {
               Opacity[0.5 (1 - $CellContext`int$$)], Blue, 
               Rectangle[{
                0, (-0.5) $CellContext`W$}, {$CellContext`L$, 
                 0.5 $CellContext`W$}]}; $CellContext`dwf2$ = {
               
               Opacity[($CellContext`opa2$$ (
                  1 - $CellContext`reac$$)) $CellContext`step1$$], 
               Line[{$CellContext`pau$, $CellContext`pad$}], 
               Line[
                
                Table[{{
                  0, $CellContext`W$ - $CellContext`W$ $CellContext`k}, \
{(-$CellContext`W$)/
                   4, $CellContext`W$ - $CellContext`W$ ($CellContext`k + 
                    0.25)}}, {$CellContext`k, 0, 1.8, 
                  0.2}]]}; $CellContext`dwf3$ = {
               
               Opacity[((1 - $CellContext`opa2$$) (
                  1 - $CellContext`reac$$)) $CellContext`step1$$], 
               Darker[Green], 
               PointSize[0.02], 
               Point[$CellContext`pa$], 
               
               Triangle[{$CellContext`pina1$, $CellContext`pina2$, \
$CellContext`pina3$}], 
               Line[{$CellContext`pinal$, $CellContext`pinar$}], 
               Line[
                
                Table[{{
                  Part[$CellContext`pinal$, 
                    1] + $CellContext`W$ ($CellContext`k + 0.15), 
                   Part[$CellContext`pinal$, 2]}, {
                  Part[$CellContext`pinal$, 
                    1] + $CellContext`W$ $CellContext`k, 
                   Part[$CellContext`pinal$, 2] - $CellContext`W$/
                   4}}, {$CellContext`k, 0, 1.7, 0.15}]], 
               Circle[$CellContext`robc$, $CellContext`robr$], 
               Line[{$CellContext`rolbr$, $CellContext`rolbl$}], 
               Line[
                
                Table[{{
                  Part[$CellContext`rolbl$, 
                    1] + $CellContext`W$ ($CellContext`k + 0.15), 
                   Part[$CellContext`rolbl$, 2]}, {
                  Part[$CellContext`rolbl$, 
                    1] + $CellContext`W$ $CellContext`k, 
                   Part[$CellContext`rolbl$, 2] - $CellContext`W$/
                   4}}, {$CellContext`k, 0, 1.7, 0.15}]]}; $CellContext`dwf4$ = {
               Opacity[(1 - $CellContext`reac$$) $CellContext`step1$$], 
               Thickness[0.005], Dashed, 
               Thickness[0.004], 
               
               Line[{{$CellContext`W$/4, 
                  0}, {$CellContext`L$ - $CellContext`W$/4, 0}}], Black, 
               Text[
               "A", $CellContext`pa$ + {
                 0.3 $CellContext`W$, $CellContext`W$}], 
               Text[
               "B", $CellContext`pb$ + {(-0.3) $CellContext`W$, \
$CellContext`W$}]}; $CellContext`dwf5$ = {
               
               Opacity[((1 (1 - $CellContext`sopa3$)) (
                  1 - $CellContext`reac$$)) $CellContext`step1$$], Black, 
               Thickness[0.005], 
               PointSize[0.01], 
               Point[$CellContext`fe$], 
               Arrowheads[0.03], 
               Arrow[{$CellContext`fi$, $CellContext`fe$}], 
               If[Norm[$CellContext`fe$ - $CellContext`fi$] > 0, 
                Text[
                "F", $CellContext`fi$ + {0.05, 0.05}]]}; $CellContext`dwf6$ = {
               
               Opacity[((1 (1 - $CellContext`sopa3$)) (
                  1 - $CellContext`int$$)) $CellContext`step1$$], Black, 
               Thickness[0.005], 
               PointSize[0.01], 
               Point[$CellContext`mp$], 
               Arrowheads[0.03], 
               Arrow[{$CellContext`mi$, $CellContext`me$}], 
               
               Circle[$CellContext`mp$, $CellContext`rm$, \
{$CellContext`sitai$, $CellContext`sitae$}], 
               If[$CellContext`mm$$ > 0, 
                If[$CellContext`dirm$$ > 0, 
                 Text[
                 "M", $CellContext`me$ + {
                   0.5 $CellContext`W$, 0.5 $CellContext`W$}], 
                 Text[
                 "M", $CellContext`me$ + {
                   0.5 $CellContext`W$, (-0.5) $CellContext`W$}]]]}; \
$CellContext`dwf7$ = {
               
               Opacity[(($CellContext`reac$$ $CellContext`opa2$$) (
                  1 - $CellContext`int$$)) $CellContext`step1$$], Red, 
               Arrowheads[0.03], 
               Thickness[0.005], 
               If[Part[$CellContext`fx$, 1] < 0, 
                
                Arrow[{$CellContext`pa$ - $CellContext`cAx$, \
$CellContext`pa$}], 
                
                Arrow[{$CellContext`pa$, $CellContext`pa$ + \
$CellContext`cAx$}]], 
               If[Norm[$CellContext`fx$] > 0, 
                If[Part[$CellContext`fx$, 1] < 0, 
                 Text[
                 "\!\(\*SubscriptBox[\(A\), \(x\)]\)", $CellContext`pa$ - \
$CellContext`cAx$ + {0, $CellContext`W$/1.5}], 
                 Text[
                 "\!\(\*SubscriptBox[\(A\), \(x\)]\)", $CellContext`pa$ + \
$CellContext`cAx$ + {0, $CellContext`W$/1.5}]]], 
               
               Arrow[{$CellContext`pa$ - $CellContext`cAy$, \
$CellContext`pa$}], 
               If[Norm[$CellContext`cAy$] > 0, 
                Text[
                "\!\(\*SubscriptBox[\(A\), \(y\)]\)", $CellContext`pa$ - \
$CellContext`cAy$ + {$CellContext`W$/1.5, 0}]], Blue, 
               If[Part[$CellContext`fx$, 1] > 0, 
                
                Arrow[{$CellContext`mAe$ + $CellContext`cAx$, \
$CellContext`mAi$ + $CellContext`cAx$}], 
                
                Arrow[{$CellContext`mAe$ - $CellContext`cAx$, \
$CellContext`mAi$ - $CellContext`cAx$}]], 
               If[Part[$CellContext`fx$, 1] < 0, 
                
                Circle[$CellContext`pa$ - $CellContext`cAx$, \
$CellContext`rMA$, {$CellContext`sitaMAi$, $CellContext`sitaMAe$}], 
                
                Circle[$CellContext`pa$ + $CellContext`cAx$, \
$CellContext`rMA$, {$CellContext`sitaMAi$, $CellContext`sitaMAe$}]], 
               If[Part[$CellContext`fx$, 1] > 0, 
                Text[
                "\!\(\*SubscriptBox[\(M\), \(A\)]\)", $CellContext`mAe$ + \
$CellContext`cAx$ + 
                 Sign[$CellContext`cMA$] {$CellContext`W$/2, $CellContext`W$/
                    1.5}], 
                Text[
                "\!\(\*SubscriptBox[\(M\), \(A\)]\)", $CellContext`mAe$ - \
$CellContext`cAx$ + 
                 Sign[$CellContext`cMA$] {$CellContext`W$/2, $CellContext`W$/
                    1.5}]], Black, 
               Arrow[{$CellContext`fe$ - $CellContext`fx$, $CellContext`fe$}], 
               If[Norm[$CellContext`fx$] > 0, 
                Text[
                "\!\(\*SubscriptBox[\(F\), \(x\)]\)", $CellContext`fe$ - \
$CellContext`fx$ + {0, $CellContext`W$/1.5}]], 
               Arrow[{$CellContext`fe$ - $CellContext`fy$, $CellContext`fe$}], 
               If[Norm[$CellContext`fy$] > 0, 
                Text[
                "\!\(\*SubscriptBox[\(F\), \(y\)]\)", $CellContext`fe$ - \
$CellContext`fy$ + {$CellContext`W$/1.5, 0}]]}; $CellContext`dwf8$ = {
               
               Opacity[(($CellContext`reac$$ (1 - $CellContext`opa2$$)) (
                  1 - $CellContext`int$$)) $CellContext`step1$$], Red, 
               Arrowheads[0.03], 
               Thickness[0.005], 
               If[Part[$CellContext`fx$, 1] < 0, 
                
                Arrow[{$CellContext`pa$ - $CellContext`sAx$ + {
                   0, (-$CellContext`W$)/2}, $CellContext`pa$ + {
                   0, (-$CellContext`W$)/2}}], 
                
                Arrow[{$CellContext`pa$ + {
                   0, (-$CellContext`W$)/
                    2}, $CellContext`pa$ + $CellContext`sAx$ + {
                   0, (-$CellContext`W$)/2}}]], 
               If[Norm[$CellContext`fx$] > 0, 
                If[Part[$CellContext`fx$, 1] < 0, 
                 Text[
                 "\!\(\*SubscriptBox[\(A\), \(x\)]\)", $CellContext`pa$ - \
$CellContext`sAx$ + {0, (-$CellContext`W$)/2} + {0, $CellContext`W$/1.5}], 
                 Text[
                 "\!\(\*SubscriptBox[\(A\), \(x\)]\)", $CellContext`pa$ + \
$CellContext`sAx$ + {0, (-$CellContext`W$)/2} + {0, $CellContext`W$/1.5}]]], 
               If[Part[$CellContext`sAy$, 2] > 0, 
                
                Arrow[{$CellContext`pa$ - $CellContext`sAy$ + {
                   0, (-$CellContext`W$)/2}, $CellContext`pa$ + {
                   0, (-$CellContext`W$)/2}}], 
                
                Arrow[{$CellContext`pa$ + {
                   0, (-$CellContext`W$)/
                    2}, $CellContext`pa$ + $CellContext`sAy$ + {
                   0, (-$CellContext`W$)/2}}]], 
               If[Norm[$CellContext`sAy$] > 0, 
                If[Part[$CellContext`sAy$, 2] > 0, 
                 Text[
                 "\!\(\*SubscriptBox[\(A\), \(y\)]\)", $CellContext`pa$ - \
$CellContext`sAy$ + {0, (-$CellContext`W$)/2} + {$CellContext`W$/1.5, 0}], 
                 Text[
                 "\!\(\*SubscriptBox[\(A\), \(y\)]\)", $CellContext`pa$ + \
$CellContext`sAy$ + {0, (-$CellContext`W$)/2} + {$CellContext`W$/1.5, 0}]]], 
               If[Part[$CellContext`sBy$, 2] > 0, 
                
                Arrow[{$CellContext`pb$ - $CellContext`sBy$ + {
                   0, (-$CellContext`W$)/2}, $CellContext`pb$ + {
                   0, (-$CellContext`W$)/2}}], 
                
                Arrow[{$CellContext`pb$ + {
                   0, (-$CellContext`W$)/
                    2}, $CellContext`pb$ + $CellContext`sBy$ + {
                   0, (-$CellContext`W$)/2}}]], 
               If[Norm[$CellContext`sBy$] > 0, 
                If[Part[$CellContext`sBy$, 2] > 0, 
                 Text[
                 "\!\(\*SubscriptBox[\(B\), \(y\)]\)", $CellContext`pb$ - \
$CellContext`sBy$ + {0, (-$CellContext`W$)/2} + {$CellContext`W$/1.5, 0}], 
                 Text[
                 "\!\(\*SubscriptBox[\(B\), \(y\)]\)", $CellContext`pb$ + \
$CellContext`sBy$ + {0, (-$CellContext`W$)/2} + {$CellContext`W$/1.5, 0}]]], 
               Black, 
               Arrow[{$CellContext`fe$ - $CellContext`fx$, $CellContext`fe$}], 
               If[Norm[$CellContext`fx$] > 0, 
                Text[
                "\!\(\*SubscriptBox[\(F\), \(x\)]\)", $CellContext`fe$ - \
$CellContext`fx$ + {0, $CellContext`W$/1.5}]], 
               Arrow[{$CellContext`fe$ - $CellContext`fy$, $CellContext`fe$}], 
               If[Norm[$CellContext`fy$] > 0, 
                Text[
                "\!\(\*SubscriptBox[\(F\), \(y\)]\)", $CellContext`fe$ - \
$CellContext`fy$ + {$CellContext`W$/1.5, 0}]]}; $CellContext`dwf9$ = {
               Opacity[$CellContext`sopa2$], 
               Thickness[0.005], Dashed, 
               Thickness[0.004], 
               Line[{$CellContext`psu$, $CellContext`psd$}], Black, 
               Text["a", $CellContext`psu$ + {0, 0.05}], 
               Text[
               "a", $CellContext`psd$ + {0, -0.05}]}; $CellContext`dwf10$ = {
               Opacity[($CellContext`sopa2$ $CellContext`int$$) 0.5], Blue, 
               
               Rectangle[{
                0, (-0.5) $CellContext`W$}, {$CellContext`ps$$, 
                 0.5 $CellContext`W$}], 
               Rectangle[{$CellContext`ps$$, (-0.5) $CellContext`W$} + {
                 0, (-10) $CellContext`W$}, {$CellContext`L$, 
                  0.5 $CellContext`W$} + {0, (-10) $CellContext`W$}], 
               Thickness[0.005], Dashed, Black, 
               Thickness[0.004], 
               Line[{$CellContext`psu$, $CellContext`psd$}], 
               
               Line[{$CellContext`psu$ + {
                  0, (-10) $CellContext`W$}, $CellContext`psd$ + {
                  0, (-10) $CellContext`W$}}], 
               Text["a", $CellContext`psu$ + {0, 0.05}], 
               Text["a", $CellContext`psd$ + {0, -0.05}], 
               Text[
               "a", $CellContext`psu$ + {0, 0.05} + {
                 0, (-10) $CellContext`W$}], 
               Text[
               "a", $CellContext`psd$ + {0, -0.05} + {
                 0, (-10) $CellContext`W$}]}; $CellContext`dwf11$ = {
               Opacity[$CellContext`sopa2$ $CellContext`int$$], Black, 
               Thickness[0.005], 
               PointSize[0.01], 
               If[$CellContext`pm$$ <= $CellContext`ps$$, 
                Point[$CellContext`mp$], 
                Point[$CellContext`mp$ + {0, (-10) $CellContext`W$}]], 
               Arrowheads[0.03], 
               If[$CellContext`pm$$ <= $CellContext`ps$$, 
                Arrow[{$CellContext`mi$, $CellContext`me$}], 
                
                Arrow[{$CellContext`mi$ + {
                   0, (-10) $CellContext`W$}, $CellContext`me$ + {
                   0, (-10) $CellContext`W$}}]], 
               If[$CellContext`pm$$ <= $CellContext`ps$$, 
                
                Circle[$CellContext`mp$, $CellContext`rm$, \
{$CellContext`sitai$, $CellContext`sitae$}], 
                
                Circle[$CellContext`mp$ + {
                  0, (-10) $CellContext`W$}, $CellContext`rm$, \
{$CellContext`sitai$, $CellContext`sitae$}]], 
               If[$CellContext`pm$$ <= $CellContext`ps$$, 
                If[$CellContext`mm$$ > 0, 
                 If[$CellContext`dirm$$ > 0, 
                  Text[
                  "M", $CellContext`me$ + {
                    0.5 $CellContext`W$, 0.5 $CellContext`W$}], 
                  Text[
                  "M", $CellContext`me$ + {
                    0.5 $CellContext`W$, (-0.5) $CellContext`W$}]]], 
                If[$CellContext`mm$$ > 0, 
                 If[$CellContext`dirm$$ > 0, 
                  Text[
                  "M", $CellContext`me$ + {
                    0.5 $CellContext`W$, 0.5 $CellContext`W$} + {
                    0, (-10) $CellContext`W$}], 
                  Text[
                  "M", $CellContext`me$ + {
                    0.5 $CellContext`W$, (-0.5) $CellContext`W$} + {
                    0, (-10) $CellContext`W$}]]]]}; $CellContext`dwf12$ = {
               Opacity[$CellContext`sopa2$ $CellContext`int$$], Black, 
               Arrowheads[0.03], 
               Thickness[0.005], 
               If[$CellContext`pf$$ <= $CellContext`ps$$, 
                
                Arrow[{$CellContext`fe$ - $CellContext`fx$, \
$CellContext`fe$}], 
                
                Arrow[{$CellContext`fe$ + {
                   0, (-10) $CellContext`W$}, $CellContext`fe$ + \
$CellContext`fx$ + {0, (-10) $CellContext`W$}}]], 
               If[$CellContext`pf$$ <= $CellContext`ps$$, 
                If[Norm[$CellContext`fx$] > 0, 
                 Text[
                 "\!\(\*SubscriptBox[\(F\), \(x\)]\)", $CellContext`fe$ - \
$CellContext`fx$ + {0, $CellContext`W$/1.5}]], 
                If[Norm[$CellContext`fx$] > 0, 
                 Text[
                 "\!\(\*SubscriptBox[\(F\), \(x\)]\)", $CellContext`fe$ + \
$CellContext`fx$ + {0, (-10) $CellContext`W$} + {0, $CellContext`W$/1.5}]]], 
               If[$CellContext`pf$$ <= $CellContext`ps$$, 
                
                Arrow[{$CellContext`fe$ - $CellContext`fy$, \
$CellContext`fe$}], 
                
                Arrow[{$CellContext`fe$ - $CellContext`fy$ + {
                   0, (-10) $CellContext`W$}, $CellContext`fe$ + {
                   0, (-10) $CellContext`W$}}]], 
               If[$CellContext`pf$$ <= $CellContext`ps$$, 
                If[Norm[$CellContext`fy$] > 0, 
                 Text[
                 "\!\(\*SubscriptBox[\(F\), \(y\)]\)", $CellContext`fe$ - \
$CellContext`fy$ + {$CellContext`W$/1.5, 0}]], 
                If[Norm[$CellContext`fy$] > 0, 
                 Text[
                 "\!\(\*SubscriptBox[\(F\), \(y\)]\)", $CellContext`fe$ - \
$CellContext`fy$ + {$CellContext`W$/1.5, 0} + {
                   0, (-10) $CellContext`W$}]]]}; $CellContext`dwf13$ = {
               
               Opacity[(($CellContext`sopa2$ $CellContext`reac$$) \
$CellContext`opa2$$) $CellContext`int$$], Red, 
               Arrowheads[0.03], 
               Thickness[0.005], 
               If[Part[$CellContext`fx$, 1] < 0, 
                
                Arrow[{$CellContext`pa$ - $CellContext`cAx$, \
$CellContext`pa$}], 
                
                Arrow[{$CellContext`pa$, $CellContext`pa$ + \
$CellContext`cAx$}]], 
               If[Norm[$CellContext`fx$] > 0, 
                If[Part[$CellContext`fx$, 1] < 0, 
                 Text[
                 "\!\(\*SubscriptBox[\(A\), \(x\)]\)", $CellContext`pa$ - \
$CellContext`cAx$ + {0, (-$CellContext`W$)/1.5}], 
                 Text[
                 "\!\(\*SubscriptBox[\(A\), \(x\)]\)", $CellContext`pa$ + \
$CellContext`cAx$ + {0, (-$CellContext`W$)/1.5}]]], 
               
               Arrow[{$CellContext`pa$ - $CellContext`cAy$, \
$CellContext`pa$}], 
               If[Norm[$CellContext`cAy$] > 0, 
                Text[
                "\!\(\*SubscriptBox[\(A\), \(y\)]\)", $CellContext`pa$ - \
$CellContext`cAy$ + {$CellContext`W$/1.5, 0}]], Blue, 
               If[Part[$CellContext`fx$, 1] > 0, 
                
                Arrow[{$CellContext`mAe$ + $CellContext`cAx$, \
$CellContext`mAi$ + $CellContext`cAx$}], 
                
                Arrow[{$CellContext`mAe$ - $CellContext`cAx$, \
$CellContext`mAi$ - $CellContext`cAx$}]], 
               If[Part[$CellContext`fx$, 1] < 0, 
                
                Circle[$CellContext`pa$ - $CellContext`cAx$, \
$CellContext`rMA$, {$CellContext`sitaMAi$, $CellContext`sitaMAe$}], 
                
                Circle[$CellContext`pa$ + $CellContext`cAx$, \
$CellContext`rMA$, {$CellContext`sitaMAi$, $CellContext`sitaMAe$}]], 
               If[Part[$CellContext`fx$, 1] > 0, 
                Text[
                "\!\(\*SubscriptBox[\(M\), \(A\)]\)", $CellContext`mAe$ + \
$CellContext`cAx$ + 
                 Sign[$CellContext`cMA$] {$CellContext`W$/2, $CellContext`W$/
                    1.5}], 
                Text[
                "\!\(\*SubscriptBox[\(M\), \(A\)]\)", $CellContext`mAe$ - \
$CellContext`cAx$ + 
                 Sign[$CellContext`cMA$] {$CellContext`W$/2, $CellContext`W$/
                    1.5}]]}; $CellContext`dwf14$ = {
               
               Opacity[(($CellContext`sopa2$ $CellContext`reac$$) (
                  1 - $CellContext`opa2$$)) $CellContext`int$$], Red, 
               Arrowheads[0.03], 
               Thickness[0.005], 
               If[Part[$CellContext`fx$, 1] < 0, 
                
                Arrow[{$CellContext`pa$ - $CellContext`sAx$, \
$CellContext`pa$}], 
                
                Arrow[{$CellContext`pa$, $CellContext`pa$ + \
$CellContext`sAx$}]], 
               If[Norm[$CellContext`fx$] > 0, 
                If[Part[$CellContext`fx$, 1] < 0, 
                 Text[
                 "\!\(\*SubscriptBox[\(A\), \(x\)]\)", $CellContext`pa$ - \
$CellContext`sAx$ + {0, $CellContext`W$/1.5}], 
                 Text[
                 "\!\(\*SubscriptBox[\(A\), \(x\)]\)", $CellContext`pa$ + \
$CellContext`sAx$ + {0, $CellContext`W$/1.5}]]], 
               If[Part[$CellContext`sAy$, 2] > 0, 
                
                Arrow[{$CellContext`pa$ - $CellContext`sAy$ + {
                   0, (-$CellContext`W$)/2}, $CellContext`pa$ + {
                   0, (-$CellContext`W$)/2}}], 
                
                Arrow[{$CellContext`pa$ + {
                   0, (-$CellContext`W$)/
                    2}, $CellContext`pa$ + $CellContext`sAy$ + {
                   0, (-$CellContext`W$)/2}}]], 
               If[Norm[$CellContext`sAy$] > 0, 
                If[Part[$CellContext`sAy$, 2] > 0, 
                 Text[
                 "\!\(\*SubscriptBox[\(A\), \(y\)]\)", $CellContext`pa$ - \
$CellContext`sAy$ + {0, (-$CellContext`W$)/2} + {$CellContext`W$/1.5, 0}], 
                 Text[
                 "\!\(\*SubscriptBox[\(A\), \(y\)]\)", $CellContext`pa$ + \
$CellContext`sAy$ + {0, (-$CellContext`W$)/2} + {$CellContext`W$/1.5, 0}]]], 
               If[Part[$CellContext`sBy$, 2] > 0, 
                
                Arrow[{$CellContext`pb$ - $CellContext`sBy$ + {
                   0, (-$CellContext`W$)/2} + {
                   0, (-10) $CellContext`W$}, $CellContext`pb$ + {
                   0, (-$CellContext`W$)/2} + {0, (-10) $CellContext`W$}}], 
                
                Arrow[{$CellContext`pb$ + {0, (-$CellContext`W$)/2} + {
                   0, (-10) $CellContext`W$}, $CellContext`pb$ + \
$CellContext`sBy$ + {0, (-$CellContext`W$)/2} + {0, (-10) $CellContext`W$}}]], 
               If[Norm[$CellContext`sBy$] > 0, 
                If[Part[$CellContext`sBy$, 2] > 0, 
                 Text[
                 "\!\(\*SubscriptBox[\(B\), \(y\)]\)", $CellContext`pb$ - \
$CellContext`sBy$ + {0, (-$CellContext`W$)/2} + {$CellContext`W$/1.5, 0} + {
                   0, (-10) $CellContext`W$}], 
                 Text[
                 "\!\(\*SubscriptBox[\(B\), \(y\)]\)", $CellContext`pb$ + \
$CellContext`sBy$ + {0, (-$CellContext`W$)/2} + {$CellContext`W$/1.5, 0} + {
                   0, (-10) $CellContext`W$}]]]}; $CellContext`dwf15$ = {
               
               Opacity[(($CellContext`sopa2$ $CellContext`reac$$) \
$CellContext`opa2$$) $CellContext`int$$], Black, 
               Arrowheads[0.03], 
               Thickness[0.005], 
               If[Part[$CellContext`cifx$, 1] > 0, 
                
                Arrow[{{$CellContext`ps$$, 
                   0}, {$CellContext`ps$$, 0} + $CellContext`cifx$}], 
                
                Arrow[{{$CellContext`ps$$, 
                    0} - $CellContext`cifx$, {$CellContext`ps$$, 0}}]], 
               If[Norm[$CellContext`cifx$] > 0, 
                If[Part[$CellContext`cifx$, 1] > 0, 
                 Text[
                 "\!\(\*SubscriptBox[\(N\), \(a\)]\)", {$CellContext`ps$$, 
                    0} + $CellContext`cifx$ + {$CellContext`W$/2, 0}], 
                 Text[
                 "\!\(\*SubscriptBox[\(N\), \(a\)]\)", {$CellContext`ps$$, 
                    0} - $CellContext`cifx$ + {$CellContext`W$/2, 0}]]], 
               If[Part[$CellContext`cifx$, 1] < 0, 
                
                Arrow[{{$CellContext`ps$$, 0} + $CellContext`cifx$ + {
                   0, (-10) $CellContext`W$}, {$CellContext`ps$$, 0} + {
                   0, (-10) $CellContext`W$}}], 
                
                Arrow[{{$CellContext`ps$$, 0} + {
                   0, (-10) $CellContext`W$}, {$CellContext`ps$$, 
                    0} - $CellContext`cifx$ + {0, (-10) $CellContext`W$}}]], 
               If[Norm[$CellContext`cifx$] > 0, 
                If[Part[$CellContext`cifx$, 1] < 0, 
                 Text[
                 "\!\(\*SubscriptBox[\(N\), \(a\)]\)", {$CellContext`ps$$, 
                    0} + $CellContext`cifx$ + {
                   0, (-10) $CellContext`W$} + {(-$CellContext`W$)/2, 0}], 
                 Text[
                 "\!\(\*SubscriptBox[\(N\), \(a\)]\)", {$CellContext`ps$$, 
                    0} - $CellContext`cifx$ + {
                   0, (-10) $CellContext`W$} + {(-$CellContext`W$)/2, 0}]]], 
               
               Arrow[{(-$CellContext`cify$)/
                  2 + {$CellContext`ps$$, 0} + {$CellContext`W$/2, 
                   0}, $CellContext`cify$/
                  2 + {$CellContext`ps$$, 0} + {$CellContext`W$/2, 0}}], 
               If[Norm[$CellContext`cify$] > 0, 
                Text[
                "\!\(\*SubscriptBox[\(V\), \(a\)]\)", $CellContext`cify$/
                  2 + {$CellContext`ps$$, 0} + {$CellContext`W$/2, 
                   0} + {$CellContext`W$/2, 0}]], 
               
               Arrow[{$CellContext`cify$/2 + {$CellContext`ps$$, 0} + {
                  0, (-10) $CellContext`W$} + {(-$CellContext`W$)/2, 
                   0}, (-$CellContext`cify$)/2 + {$CellContext`ps$$, 0} + {
                  0, (-10) $CellContext`W$} + {(-$CellContext`W$)/2, 0}}], 
               If[Norm[$CellContext`cify$] > 0, 
                Text[
                "\!\(\*SubscriptBox[\(V\), \(a\)]\)", (-$CellContext`cify$)/
                  2 + {$CellContext`ps$$, 0} + {
                  0, (-10) $CellContext`W$} + {(-$CellContext`W$)/2, 
                   0} + {(-$CellContext`W$)/2, 0}]], 
               Darker[Purple], 
               If[Part[$CellContext`cifx$, 1] > 0, 
                
                Circle[{$CellContext`ps$$, 
                   0} + $CellContext`cifx$, $CellContext`rMs$, \
{$CellContext`csitaiMsi$, $CellContext`csitaiMse$}], 
                
                Circle[{$CellContext`ps$$, 
                   0} - $CellContext`cifx$, $CellContext`rMs$, \
{$CellContext`csitaiMsi$, $CellContext`csitaiMse$}]], 
               If[Norm[$CellContext`ciMs$] > 0.0001, 
                If[Part[$CellContext`cifx$, 1] > 0, 
                 
                 Arrow[{$CellContext`cmse$ + $CellContext`cifx$ + \
{$CellContext`ps$$, 
                    0}, $CellContext`cmsi$ + $CellContext`cifx$ + \
{$CellContext`ps$$, 0}}], 
                 
                 Arrow[{$CellContext`cmse$ - $CellContext`cifx$ + \
{$CellContext`ps$$, 
                    0}, $CellContext`cmsi$ - $CellContext`cifx$ + \
{$CellContext`ps$$, 0}}]]], 
               If[Norm[$CellContext`ciMs$] > 0.0001, 
                If[Part[$CellContext`cifx$, 1] > 0, 
                 Text[
                 "\!\(\*SubscriptBox[\(M\), \(a\)]\)", $CellContext`cmse$ + \
$CellContext`cifx$ + 
                  Sign[$CellContext`ciMs$] {$CellContext`W$/
                    2, $CellContext`W$/1.5} + {$CellContext`ps$$, 0}], 
                 Text[
                 "\!\(\*SubscriptBox[\(M\), \(a\)]\)", $CellContext`cmse$ - \
$CellContext`cifx$ + 
                  Sign[$CellContext`ciMs$] {$CellContext`W$/
                    2, $CellContext`W$/1.5} + {$CellContext`ps$$, 0}]]], 
               If[Part[$CellContext`cifx$, 1] > 0, 
                
                Circle[{$CellContext`ps$$, 0} - $CellContext`cifx$ + {
                  0, (-10) $CellContext`W$}, $CellContext`rMs$, {
                 Pi - $CellContext`csitaiMsi$, Pi - $CellContext`csitaiMse$}], 
                
                Circle[{$CellContext`ps$$, 0} + $CellContext`cifx$ + {
                  0, (-10) $CellContext`W$}, $CellContext`rMs$, {
                 Pi - $CellContext`csitaiMsi$, 
                  Pi - $CellContext`csitaiMse$}]], 
               If[Norm[$CellContext`ciMs$] > 0.0001, 
                If[Part[$CellContext`cifx$, 1] > 0, 
                 
                 Arrow[{$CellContext`cmsed$ - $CellContext`cifx$ + \
{$CellContext`ps$$, 0} + {
                    0, (-10) $CellContext`W$}, $CellContext`cmsid$ - \
$CellContext`cifx$ + {$CellContext`ps$$, 0} + {0, (-10) $CellContext`W$}}], 
                 
                 Arrow[{$CellContext`cmsed$ + $CellContext`cifx$ + \
{$CellContext`ps$$, 0} + {
                    0, (-10) $CellContext`W$}, $CellContext`cmsid$ + \
$CellContext`cifx$ + {$CellContext`ps$$, 0} + {0, (-10) $CellContext`W$}}]]], 
               If[Norm[$CellContext`ciMs$] > 0.0001, 
                If[Part[$CellContext`cifx$, 1] > 0, 
                 Text[
                 "\!\(\*SubscriptBox[\(M\), \(a\)]\)", $CellContext`cmsed$ - \
$CellContext`cifx$ + 
                  Sign[$CellContext`ciMs$] {(-$CellContext`W$)/
                    2, $CellContext`W$/1.5} + {$CellContext`ps$$, 0} + {
                   0, (-10) $CellContext`W$}], 
                 Text[
                 "\!\(\*SubscriptBox[\(M\), \(a\)]\)", $CellContext`cmsed$ + \
$CellContext`cifx$ + 
                  Sign[$CellContext`ciMs$] {(-$CellContext`W$)/
                    2, $CellContext`W$/1.5} + {$CellContext`ps$$, 0} + {
                   0, (-10) $CellContext`W$}]]]}; $CellContext`dwf16$ = {
               
               Opacity[(($CellContext`sopa2$ $CellContext`reac$$) (
                  1 - $CellContext`opa2$$)) $CellContext`int$$], Black, 
               Arrowheads[0.03], 
               Thickness[0.005], 
               If[Part[$CellContext`sifx$, 1] > 0, 
                
                Arrow[{{$CellContext`ps$$, 
                   0}, {$CellContext`ps$$, 0} + $CellContext`sifx$}], 
                
                Arrow[{{$CellContext`ps$$, 
                    0} - $CellContext`sifx$, {$CellContext`ps$$, 0}}]], 
               If[Norm[$CellContext`sifx$] > 0, 
                If[Part[$CellContext`sifx$, 1] > 0, 
                 Text[
                 "\!\(\*SubscriptBox[\(N\), \(a\)]\)", {$CellContext`ps$$, 
                    0} + $CellContext`sifx$ + {$CellContext`W$/2, 0}], 
                 Text[
                 "\!\(\*SubscriptBox[\(N\), \(a\)]\)", {$CellContext`ps$$, 
                    0} - $CellContext`sifx$ + {$CellContext`W$/2, 0}]]], 
               If[Part[$CellContext`sifx$, 1] < 0, 
                
                Arrow[{{$CellContext`ps$$, 0} + $CellContext`sifx$ + {
                   0, (-10) $CellContext`W$}, {$CellContext`ps$$, 0} + {
                   0, (-10) $CellContext`W$}}], 
                
                Arrow[{{$CellContext`ps$$, 0} + {
                   0, (-10) $CellContext`W$}, {$CellContext`ps$$, 
                    0} - $CellContext`sifx$ + {0, (-10) $CellContext`W$}}]], 
               If[Norm[$CellContext`sifx$] > 0, 
                If[Part[$CellContext`sifx$, 1] < 0, 
                 Text[
                 "\!\(\*SubscriptBox[\(N\), \(a\)]\)", {$CellContext`ps$$, 
                    0} + $CellContext`sifx$ + {
                   0, (-10) $CellContext`W$} + {(-$CellContext`W$)/2, 0}], 
                 Text[
                 "\!\(\*SubscriptBox[\(N\), \(a\)]\)", {$CellContext`ps$$, 
                    0} - $CellContext`sifx$ + {
                   0, (-10) $CellContext`W$} + {(-$CellContext`W$)/2, 0}]]], 
               
               Arrow[{(-$CellContext`sify$)/
                  2 + {$CellContext`ps$$, 0} + {$CellContext`W$/2, 
                   0}, $CellContext`sify$/
                  2 + {$CellContext`ps$$, 0} + {$CellContext`W$/2, 0}}], 
               If[Norm[$CellContext`sify$] > 0, 
                Text[
                "\!\(\*SubscriptBox[\(V\), \(a\)]\)", $CellContext`sify$/
                  2 + {$CellContext`ps$$, 0} + {$CellContext`W$/2, 
                   0} + {$CellContext`W$/2, 0}]], 
               
               Arrow[{$CellContext`sify$/2 + {$CellContext`ps$$, 0} + {
                  0, (-10) $CellContext`W$} + {(-$CellContext`W$)/2, 
                   0}, (-$CellContext`sify$)/2 + {$CellContext`ps$$, 0} + {
                  0, (-10) $CellContext`W$} + {(-$CellContext`W$)/2, 0}}], 
               If[Norm[$CellContext`sify$] > 0, 
                Text[
                "\!\(\*SubscriptBox[\(V\), \(a\)]\)", (-$CellContext`sify$)/
                  2 + {$CellContext`ps$$, 0} + {
                  0, (-10) $CellContext`W$} + {(-$CellContext`W$)/2, 
                   0} + {(-$CellContext`W$)/2, 0}]], 
               Darker[Purple], 
               If[Part[$CellContext`sifx$, 1] > 0, 
                
                Circle[{$CellContext`ps$$, 
                   0} + $CellContext`sifx$, $CellContext`rMs$, \
{$CellContext`ssitaiMsi$, $CellContext`ssitaiMse$}], 
                
                Circle[{$CellContext`ps$$, 
                   0} - $CellContext`sifx$, $CellContext`rMs$, \
{$CellContext`ssitaiMsi$, $CellContext`ssitaiMse$}]], 
               If[Norm[$CellContext`siMs$] > 0.0001, 
                If[Part[$CellContext`sifx$, 1] > 0, 
                 
                 Arrow[{$CellContext`smsi$ + $CellContext`sifx$ + \
{$CellContext`ps$$, 
                    0}, $CellContext`smse$ + $CellContext`sifx$ + \
{$CellContext`ps$$, 0}}], 
                 
                 Arrow[{$CellContext`smsi$ - $CellContext`sifx$ + \
{$CellContext`ps$$, 
                    0}, $CellContext`smse$ - $CellContext`sifx$ + \
{$CellContext`ps$$, 0}}]]], 
               If[Norm[$CellContext`siMs$] > 0.0001, 
                If[Part[$CellContext`sifx$, 1] > 0, 
                 Text[
                 "\!\(\*SubscriptBox[\(M\), \(a\)]\)", $CellContext`smse$ + \
$CellContext`sifx$ + 
                  Sign[$CellContext`siMs$] {$CellContext`W$/
                    2, $CellContext`W$/1.5} + {$CellContext`ps$$, 0}], 
                 Text[
                 "\!\(\*SubscriptBox[\(M\), \(a\)]\)", $CellContext`smse$ - \
$CellContext`sifx$ + 
                  Sign[$CellContext`siMs$] {$CellContext`W$/
                    2, $CellContext`W$/1.5} + {$CellContext`ps$$, 0}]]], 
               If[Part[$CellContext`sifx$, 1] > 0, 
                
                Circle[{$CellContext`ps$$, 0} - $CellContext`sifx$ + {
                  0, (-10) $CellContext`W$}, $CellContext`rMs$, \
{$CellContext`ssitaiMsid$, $CellContext`ssitaiMsed$}], 
                
                Circle[{$CellContext`ps$$, 0} + $CellContext`sifx$ + {
                  0, (-10) $CellContext`W$}, $CellContext`rMs$, \
{$CellContext`ssitaiMsid$, $CellContext`ssitaiMsed$}]], 
               If[Norm[$CellContext`siMs$] > 0.0001, 
                If[Part[$CellContext`sifx$, 1] > 0, 
                 
                 Arrow[{$CellContext`smsid$ - $CellContext`sifx$ + \
{$CellContext`ps$$, 0} + {
                    0, (-10) $CellContext`W$}, $CellContext`smsed$ - \
$CellContext`sifx$ + {$CellContext`ps$$, 0} + {0, (-10) $CellContext`W$}}], 
                 
                 Arrow[{$CellContext`smsid$ + $CellContext`sifx$ + \
{$CellContext`ps$$, 0} + {
                    0, (-10) $CellContext`W$}, $CellContext`smsed$ + \
$CellContext`sifx$ + {$CellContext`ps$$, 0} + {0, (-10) $CellContext`W$}}]]], 
               If[Norm[$CellContext`siMs$] > 0.0001, 
                If[Part[$CellContext`sifx$, 1] > 0, 
                 Text[
                 "\!\(\*SubscriptBox[\(M\), \(a\)]\)", $CellContext`smsed$ - \
$CellContext`sifx$ + Sign[$CellContext`siMs$] {(-$CellContext`W$)/
                    2, $CellContext`W$/1.5} + {$CellContext`ps$$, 0} + {
                   0, (-10) $CellContext`W$}], 
                 Text[
                 "\!\(\*SubscriptBox[\(M\), \(a\)]\)", $CellContext`smsed$ + \
$CellContext`sifx$ + 
                  Sign[$CellContext`siMs$] {(-$CellContext`W$)/
                    2, $CellContext`W$/1.5} + {$CellContext`ps$$, 0} + {
                   0, (-10) $CellContext`W$}]]]}; $CellContext`dw1 = 
             Graphics[{$CellContext`dwf0$, $CellContext`dwf1$, \
$CellContext`dwf2$, $CellContext`dwf3$, $CellContext`dwf4$, \
$CellContext`dwf5$, $CellContext`dwf6$, $CellContext`dwf7$, \
$CellContext`dwf8$, $CellContext`dwf9$, $CellContext`dwf10$, \
$CellContext`dwf11$, $CellContext`dwf12$, $CellContext`dwf13$, \
$CellContext`dwf14$, $CellContext`dwf15$, $CellContext`dwf16$}, 
               PlotRange -> {{(-0.5) $CellContext`size$, 
                  1.5 $CellContext`size$}, {(-1.8) $CellContext`size$, 
                  0.8 $CellContext`size$}}, ImageSize -> 400, Frame -> True]; 
            Show[$CellContext`dw1]], 
           Item[
            Column[{
              Grid[{{
                 PaneSelector[{
                   Item[$CellContext`normal$, ItemSize -> Full]}, 
                  Dynamic[$CellContext`nd$$ $CellContext`step3$$]]}, {
                 PaneSelector[{
                   Item[$CellContext`shear$, ItemSize -> Full]}, 
                  Dynamic[$CellContext`sd$$ $CellContext`step3$$]]}, {
                 PaneSelector[{
                   Item[$CellContext`moment$, ItemSize -> Full]}, 
                  Dynamic[$CellContext`bd$$ $CellContext`step3$$]]}}, 
               Alignment -> Left, Spacings -> {Automatic, 2.1}]}], 
            ControlPlacement -> Right]}]], 
      "Specifications" :> {{{$CellContext`opa1$$, 0, 
          Row[{"Coordinates visibility", 
            Spacer[55]}]}, {1 -> "On", 0 -> "off"}, ControlType -> 
         RadioButton, ControlPlacement -> 1}, {{$CellContext`step1$$, 0, 
          
          Row[{"\!\(\*\nStyleBox[\"Step\",\nFontWeight->\"Bold\"]\)\!\(\*\n\
StyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"I\",\nFontWeight->\
\"Bold\"]\)\!\(\*\nStyleBox[\":\",\nFontWeight->\"Bold\"]\)\!\(\*\n\
StyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"External\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\"loadings\",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"on\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\"the\",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"beam\",\nFontWeight->\"Bold\"]\)", 
            Spacer[65]}]}, {
         1 -> "\!\(\*\nStyleBox[\"On\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 0 -> 
          "\!\(\*\nStyleBox[\"off\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)"}, ControlType -> SetterBar, 
         ControlPlacement -> 2}, {{$CellContext`opa2$$, 1, 
          Row[{"Types of Beam", 
            Spacer[85]}]}, {
         1 -> "\!\(\*\nStyleBox[\"Cantilever\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 0 -> 
          "\!\(\*\nStyleBox[\"Simply\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"-\",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"Supported\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)"}, ControlType -> 
         SetterBar, ControlPlacement -> 3}, {{$CellContext`pf$$, 0.4, 
          Row[{"Position of force [m]", 
            Spacer[60]}]}, 0, 1, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 4}, {{$CellContext`mf$$, 0.25, 
          
          Row[{"\!\(\*\nStyleBox[\"Magnitude\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\" \",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"of\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"force\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"[\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"kN\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"]\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 
            Spacer[39]}]}, 0, 0.5, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 5}, {{$CellContext`dirf$$, 120, 
          
          Row[{"\!\(\*\nStyleBox[\"Direction\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\" \",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"of\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"Force\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"[\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"\[Degree]\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"]\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 
            Spacer[58]}]}, 0, 360, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 6}, {{$CellContext`pm$$, 0.6, 
          
          Row[{"\!\(\*\nStyleBox[\"Position\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\" \",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"of\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"moment\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"[\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"m\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"]\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 
            Spacer[43]}]}, 0, 1, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 7}, {{$CellContext`mm$$, 0.25, 
          
          Row[{"\!\(\*\nStyleBox[\"Magnitude\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\" \",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"of\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"moment\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"[\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"kN\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"\[CenterDot]\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"m\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"]\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 
            Spacer[8]}]}, 0, 0.5, ImageSize -> Small, Appearance -> "Labeled",
          ControlPlacement -> 8}, {{$CellContext`dirm$$, 1, 
          
          Row[{"\!\(\*\nStyleBox[\"Direction\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\" \",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"of\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"Moment\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 
            Spacer[53]}]}, {1 -> "CCW", 0 -> "CW"}, ControlType -> SetterBar, 
         ControlPlacement -> 9}, {{$CellContext`reac$$, 0, 
          Row[{"Reactive Force & Moment", 
            Spacer[26.5]}]}, {1 -> "On", 0 -> "Off"}, ControlType -> 
         SetterBar, ControlPlacement -> 10}, {{$CellContext`step2$$, 0, 
          
          Row[{"\!\(\*\nStyleBox[\"Step\",\nFontWeight->\"Bold\"]\)\!\(\*\n\
StyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"II\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\":\",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"Internal\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\"forces\",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"in\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\"the\",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"beam\",\nFontWeight->\"Bold\"]\)", 
            Spacer[75]}]}, {
         1 -> "\!\(\*\nStyleBox[\"On\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 0 -> 
          "\!\(\*\nStyleBox[\"off\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)"}, ControlType -> SetterBar, 
         ControlPlacement -> 11}, {{$CellContext`ps$$, 0.25, 
          Row[{"Position of section [m]", 
            Spacer[43]}]}, 0.01, 0.99, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 12}, {{$CellContext`int$$, 0, 
          Row[{"Internal Forces", 
            Spacer[85]}]}, {1 -> "On", 0 -> "Off"}, ControlType -> SetterBar, 
         ControlPlacement -> 13}, {{$CellContext`step3$$, 0, 
          
          Row[{"\!\(\*\nStyleBox[\"Step\",\nFontWeight->\"Bold\"]\)\!\(\*\n\
StyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"III\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\":\",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"Internal\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\"force\",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"diagrams\",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\
\nStyleBox[\"of\",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"the\",\nFontWeight->\"Bold\"]\)\!\(\
\*\nStyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"beam\",\n\
FontWeight->\"Bold\"]\)", 
            Spacer[20]}]}, {
         1 -> "\!\(\*\nStyleBox[\"On\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 0 -> 
          "\!\(\*\nStyleBox[\"off\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)"}, ControlType -> SetterBar, 
         ControlPlacement -> 14}, {{$CellContext`nd$$, 1, 
          Row[{"Normal Force Diagram", 
            Spacer[40]}]}, {1 -> "On", 0 -> "Off"}, ControlType -> SetterBar, 
         ControlPlacement -> 15}, {{$CellContext`sd$$, 1, 
          Row[{"Shear Force Diagram", 
            Spacer[50]}]}, {1 -> "On", 0 -> "Off"}, ControlType -> SetterBar, 
         ControlPlacement -> 16}, {{$CellContext`bd$$, 1, 
          Row[{"Bending Moment Diagram", 
            Spacer[20]}]}, {1 -> "On", 0 -> "Off"}, ControlType -> SetterBar, 
         ControlPlacement -> 17}, 
        Item[
         Column[{
           Grid[{{
              Manipulate`Place[1]}, {
              Manipulate`Place[2]}, {
              PaneSelector[{1 -> Column[{
                   Row[{
                    Manipulate`Place[3]}], 
                   Row[{
                    Manipulate`Place[4]}], 
                   Row[{
                    Manipulate`Place[5]}], 
                   Row[{
                    Manipulate`Place[6]}], 
                   Row[{
                    Manipulate`Place[7]}], 
                   Row[{
                    Manipulate`Place[8]}], 
                   Row[{
                    Manipulate`Place[9]}], 
                   Row[{
                    Manipulate`Place[10]}], 
                   Row[{
                    Dynamic[
                    
                    If[$CellContext`reac$$ $CellContext`step1$$ == 
                    1, $CellContext`temp1, 
                    Invisible[$CellContext`temp]]]}]}]}, 
               Dynamic[$CellContext`step1$$]]}, {
              
              Row[{"---------------------------------------------------------\
"}]}, {
              Manipulate`Place[11]}, {
              PaneSelector[{
                Column[{
                  Row[{
                    Manipulate`Place[12]}], 
                  Row[{
                    Manipulate`Place[13]}], 
                  Row[{
                    Dynamic[
                    If[$CellContext`int$$ == 1, $CellContext`temp2, 
                    Invisible[$CellContext`temp]]]}]}]}, 
               Dynamic[$CellContext`step2$$]]}, {
              
              Row[{"---------------------------------------------------------\
"}]}, {
              Manipulate`Place[14]}, {
              PaneSelector[{
                Column[{
                  Row[{
                    Manipulate`Place[15]}], 
                  Row[{
                    Manipulate`Place[16]}], 
                  Row[{
                    Manipulate`Place[17]}]}]}, 
               Dynamic[$CellContext`step3$$]]}}, Alignment -> Left, 
            Spacings -> {Automatic, 1.5}]}], ControlPlacement -> Left]}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{1155., {298., 304.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 TextAlignment->Center,
 ExpressionUUID -> "ac3680f3-7eea-495b-b930-cbfbff757df0"]
}, Open  ]]
},
WindowSize->{1366, 685},
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->Automatic,
CellContext->Notebook,
TrackCellChangeTimes->False,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]]}, WindowSize -> {775, 561}, 
  WindowMargins -> {{25, Automatic}, {Automatic, 31}}, FrontEndVersion -> 
  "11.0 for Microsoft Windows (64-bit) (July 28, 2016)", StyleDefinitions -> 
  "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 264, 7, 155, "Title"],
Cell[1753, 44, 1122, 24, 144, "Text"],
Cell[2878, 70, 94550, 1788, 619, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature UuDw4#0RYIKckCw5SWRh#Bhs *)
